@@ -19,16 +19,18 @@ package org.sqlite;
 import java.sql.*;
 import java.util.Properties;
 import java.util.logging.Logger;
+import org.slf4j.LoggerFactory;
 import org.sqlite.jdbc4.JDBC4Connection;
 
 public class JDBC implements Driver {
+    private static final org.slf4j.Logger logger = LoggerFactory.getLogger(JDBC.class);
     public static final String PREFIX = "jdbc:sqlite:";
 
     static {
         try {
             DriverManager.registerDriver(new JDBC());
         } catch (SQLException e) {
-            e.printStackTrace();
+            logger.error("Could not register driver", e);
         }
     }
 
