@@ -54,7 +54,7 @@ public class SQLiteConfig {
     private final Properties pragmaTable;
     private int openModeFlag = 0x00;
 
-    private final int busyTimeout;
+    private int busyTimeout;
     private boolean explicitReadOnly;
 
     private final SQLiteConnectionConfig defaultConnectionConfig;
@@ -87,8 +87,8 @@ public class SQLiteConfig {
         // Enable URI filenames
         setOpenMode(SQLiteOpenMode.OPEN_URI);
 
-        this.busyTimeout =
-                Integer.parseInt(pragmaTable.getProperty(Pragma.BUSY_TIMEOUT.pragmaName, "3000"));
+        setBusyTimeout(
+                Integer.parseInt(pragmaTable.getProperty(Pragma.BUSY_TIMEOUT.pragmaName, "3000")));
         this.defaultConnectionConfig = SQLiteConnectionConfig.fromPragmaTable(pragmaTable);
         this.explicitReadOnly =
                 Boolean.parseBoolean(
@@ -258,7 +258,7 @@ public class SQLiteConfig {
     }
 
     /**
-     * Retrives a pragma integer value.
+     * Retrieves a pragma integer value.
      *
      * @param pragma The pragma.
      * @param defaultValue The default value.
@@ -425,6 +425,7 @@ public class SQLiteConfig {
                 "journal_size_limit",
                 "Limit the size of rollback-journal and WAL files left in the file-system after transactions or checkpoints",
                 null),
+        LEGACY_ALTER_TABLE("legacy_alter_table", "Use legacy alter table behavior", OnOff),
         LEGACY_FILE_FORMAT("legacy_file_format", "No-op", OnOff),
         LOCKING_MODE(
                 "locking_mode",
@@ -837,7 +838,7 @@ public class SQLiteConfig {
      * @see <a
      *     href="https://www.sqlite.org/pragma.html#pragma_journal_size_limit">www.sqlite.org/pragma.html#pragma_journal_size_limit</a>
      */
-    public void setJounalSizeLimit(int limit) {
+    public void setJournalSizeLimit(int limit) {
         set(Pragma.JOURNAL_SIZE_LIMIT, limit);
     }
 
@@ -855,6 +856,19 @@ public class SQLiteConfig {
         set(Pragma.LEGACY_FILE_FORMAT, use);
     }
 
+    /**
+     * Sets the value of the legacy_alter_table flag. When this flag is on, the ALTER TABLE RENAME
+     * command (for changing the name of a table) works as it did in SQLite 3.24.0 (2018-06-04) and
+     * earlier.When the flag is off, using the ALTER TABLE RENAME command will mean that all
+     * references to the table anywhere in the schema will be converted to the new name.
+     *
+     * @param flag True to turn on legacy alter table behaviour; false to turn off.
+     * @see <a href="https://www.sqlite.org/pragma.html#pragma_legacy_alter_table</a>
+     */
+    public void setLegacyAlterTable(boolean flag) {
+        set(Pragma.LEGACY_ALTER_TABLE, flag);
+    }
+
     public enum LockingMode implements PragmaValue {
         NORMAL,
         EXCLUSIVE;
@@ -899,14 +913,14 @@ public class SQLiteConfig {
     }
 
     /**
-     * Enables or disables useReadUncommitedIsolationMode.
+     * Enables or disables useReadUncommittedIsolationMode.
      *
-     * @param useReadUncommitedIsolationMode True to turn on; false to disable. disabled otherwise.
+     * @param useReadUncommittedIsolationMode True to turn on; false to disable. disabled otherwise.
      * @see <a
      *     href="https://www.sqlite.org/pragma.html#pragma_read_uncommitted">www.sqlite.org/pragma.html#pragma_read_uncommitted</a>
      */
-    public void setReadUncommited(boolean useReadUncommitedIsolationMode) {
-        set(Pragma.READ_UNCOMMITTED, useReadUncommitedIsolationMode);
+    public void setReadUncommitted(boolean useReadUncommittedIsolationMode) {
+        set(Pragma.READ_UNCOMMITTED, useReadUncommittedIsolationMode);
     }
 
     /**
@@ -1070,9 +1084,6 @@ public class SQLiteConfig {
     }
 
     public enum TransactionMode implements PragmaValue {
-        /** @deprecated Use {@code DEFERRED} instead. */
-        @Deprecated
-        DEFFERED,
         DEFERRED,
         IMMEDIATE,
         EXCLUSIVE;
@@ -1082,9 +1093,6 @@ public class SQLiteConfig {
         }
 
         public static TransactionMode getMode(String mode) {
-            if ("DEFFERED".equalsIgnoreCase(mode)) {
-                return DEFERRED;
-            }
             return TransactionMode.valueOf(mode.toUpperCase());
         }
     }
@@ -1162,6 +1170,7 @@ public class SQLiteConfig {
     /** @param milliseconds Connect to DB timeout in milliseconds */
     public void setBusyTimeout(int milliseconds) {
         setPragma(Pragma.BUSY_TIMEOUT, Integer.toString(milliseconds));
+        busyTimeout = milliseconds;
     }
 
     public int getBusyTimeout() {
